@@ -5,11 +5,11 @@ overdisp.glmer <- function(model) {
   vpars <- function(m) {
     nrow(m)*(nrow(m)+1)/2
   }
-  model.df <- sum(sapply(VarCorr(model),vpars))+length(fixef(model))
+  model.df <- sum(sapply(lme4::VarCorr(model),vpars))+length(lme4::fixef(model))
   rdf <- nrow(model.frame(model))-model.df
   rp <- residuals(model)
   dev <- sum(rp^2)
   prat <- dev/rdf
   cat(paste("Residual deviance: ",round(dev,3)," on ",rdf," degrees of freedom",
     " (ratio: ",round(prat,3),")\n",sep=""))
-}
\ No newline at end of file
+}
